# -*- coding: utf-8 -*-

import numpy as np
import scipy.stats as stat

#numpy vector of floats
#http://www.statsci.org/data/general/shoshoni.html
#two outliers are removed
d = np.array([0.553,0.57,0.576,0.601,0.606,0.606,0.609,0.611,0.615,0.628,0.654,0.662,0.668,0.67,0.672,0.69,0.693,0.749])

#descriptive statistics
stat_des = stat.describe(d)
print(stat_des)

#stat_des is of the type "namedtuple" from the collections module
#various ways to access to the results

#using the index
print(stat_des[0])

#using the name
print(stat_des.nobs)

#multiple assignment
n,mm,m,v,sk,kt = stat.describe(d)
print(n,m)

#median from NumPy library
print(np.median(d))

#percentile rank of a score
print(stat.percentileofscore(d,0.6215))

#graphical representation
import matplotlib as mp

#histogram
mp.pyplot.hist(d,bins=5)

#quantiles and cumulative distribution functions

#standard normal distribution
print(stat.norm.ppf(0.95,loc=0,scale=1))
print(stat.norm.cdf(1.96,loc=0,scale=1))

#Student distribution
print(stat.t.ppf(0.95,df=30))
print(stat.t.cdf(1.96,df=30))

#chi-squared distribution
print(stat.chi.ppf(0.95,df=10))
print(stat.chi.cdf(4.84,df=10))

#F-distribution
print(stat.f.ppf(0.95,dfn=1,dfd=30))
print(stat.f.cdf(3.48,dfn=1,dfd=30))

#D'Agostino and Pearson's test
ag = stat.normaltest(d)
print(ag)

#Shapiro-Wilks' normality test
sp = stat.shapiro(d)
print(sp)

#Anderson-Darling test
ad = stat.anderson(d,dist="norm")
print(ad)

#comparison to an assumed mean
print(stat.ttest_1samp(d,popmean=0.618))

#we can detail the calculations
#sample mean
m = np.mean(d)
#sample standard deviation (n-1)
sigma = np.std(d,ddof=1)
#test statistic
import math
t = (m - 0.618)/(sigma/math.sqrt(d.size))
print(t)

#p-value - non-directional test
p = 2.0 * (1.0 - stat.t.cdf(math.fabs(t),d.size-1))
print(p)

#random sample - standard normal distribution
alea1 = stat.norm.rvs(loc=0,scale=1,size=30)
print(stat.skew(alea1,bias=False))
print(stat.kurtosis(alea1,fisher=True,bias=False))
print(stat.normaltest(alea1))

#exponential distribution
alea2 = stat.expon.rvs(size=30)
print(stat.skew(alea2,bias=False))
print(stat.kurtosis(alea2,fisher=True,bias=False))
print(stat.normaltest(alea2))

#Numpy has also a generator
alea3 = np.random.normal(loc=0,scale=1,size=30)
print(stat.skew(alea1,bias=False))
print(stat.kurtosis(alea1,fisher=True,bias=False))
print(stat.normaltest(alea3))

#sampling size = 5 instances from d
d1 = np.random.choice(d,size=5,replace=False)
print(d1)

#sampling with replacement
d2 = np.random.choice(d,size=5,replace=True)
print(d2)
